@@ -31,6 +31,7 @@
 #include "resourceterm.h"
 #include "resourcetypeterm.h"
 #include "optionalterm.h"
+#include "literal.h"
 
 #include "nie.h"
 #include "nfo.h"
@@ -113,24 +114,12 @@ QString Nepomuk2::Utils::formatPropertyValue( const Nepomuk2::Types::Property& p
     }
 
     // do not use else here since the above code might fall through
-
     QString valueString;
-    if (value.isDateTime()) {
-        valueString = KGlobal::locale()->formatDateTime(value.toDateTime(), KLocale::FancyLongDate);
-    }
+    KUrl additionalResourceUri;
 
-    else if(value.isDouble()) {
-        valueString = KGlobal::locale()->formatNumber(value.toDouble());
-    }
-
-    else if(value.isInt() && property == Vocabulary::NFO::duration() ) {
-        QTime time = QTime().addSecs( value.toInt() );
-        valueString = KGlobal::locale()->formatTime( time, true, true );
-    }
-
-    else if(value.isResource() &&
-            value.toResource().exists()) {
+    if(value.isResource() && value.toResource().exists()) {
         valueString = value.toResource().genericLabel();
+        additionalResourceUri = value.toUrl();
     }
 
     else if(property == Vocabulary::NIE::contentSize()) {
@@ -142,16 +131,45 @@ QString Nepomuk2::Utils::formatPropertyValue( const Nepomuk2::Types::Property& p
         valueString = (mimeType ? mimeType->comment() : value.toString());
     }
 
-    else {
-        valueString = value.toString();
+    else if(property == Vocabulary::NFO::duration() ) {
+        QTime time = QTime().addSecs( value.toInt() );
+        valueString = KGlobal::locale()->formatTime( time, true, true );
+    }
+
+    if( valueString.isEmpty() && ResourceManager::instance()->initialized() ) {
+        Types::Literal literalRange = property.literalRangeType();
+        QVariant::Type dataType = literalRange.dataType();
+        if( !literalRange.isValid() )
+            dataType = value.variant().type();
+
+        switch( dataType ) {
+            case QVariant::DateTime:
+                valueString = KGlobal::locale()->formatDateTime(value.toDateTime(), KLocale::FancyLongDate);
+                break;
+            case QVariant::Date:
+                valueString = KGlobal::locale()->formatDate(value.toDate(), KLocale::FancyLongDate);
+                break;
+            case QVariant::Int:
+                valueString = KGlobal::locale()->formatLong(value.toInt());
+                break;
+            case QVariant::Double:
+                valueString = KGlobal::locale()->formatNumber(value.toDouble());
+                break;
+            default:
+                valueString = value.toString();
+                break;
+        }
     }
 
     if( flags & WithKioLinks ) {
         // for all property/value pairs we create a default query
         Nepomuk2::Query::FileQuery query( Nepomuk2::Query::Term::fromProperty(property, value) );
-        return QString::fromLatin1("<a href=\"%1\">%2</a>")
-            .arg(query.toSearchUrl(property.label() + QLatin1String(": '") + valueString + '\'').url(),
-                 valueString);
+        KUrl searchUrl = query.toSearchUrl(property.label() + QLatin1String(": '") + valueString + '\'');
+        if( !additionalResourceUri.isEmpty() ) {
+            searchUrl.addQueryItem( QLatin1String("resource"), additionalResourceUri.url() );
+        }
+
+        return QString::fromLatin1("<a href=\"%1\">%2</a>").arg( searchUrl.url(), valueString);
     }
     else {
         return valueString;
